@@ -426,7 +426,7 @@ sub replace_media_listen {
 ###########################################################################
 
 my $RX_IP4 = do {
-	my $part = qr{2(?:[0-4]\d|5[0-5]|\d)|[01]\d{0,2}|[3-9]\d};
+	my $part = qr{2(?:[0-4]\d|5[0-5]|\d?)|[01]\d{0,2}|[3-9]\d?};
 	qr{^$part\.$part\.$part\.$part$}
 };
 my $RX_IP6 = do {
